==> mingw-w64-arrow-14.0.2-1.src.tar.zst: apache-arrow-14.0.2/java/adapter/jdbc/src/test/java/org/apache/arrow/adapter/jdbc/JdbcFieldInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.arrow.adapter.jdbc;

import static org.junit.Assert.*;

import java.sql.Types;

import org.junit.Test;

public class JdbcFieldInfoTest {

  @Test
  public void testCreateJdbcFieldInfoWithJdbcType() {
    JdbcFieldInfo fieldInfo = new JdbcFieldInfo(Types.BLOB);

    assertEquals(Types.BLOB, fieldInfo.getJdbcType());
    assertEquals(0, fieldInfo.getPrecision());
    assertEquals(0, fieldInfo.getScale());
  }

  @Test
  public void testCreateJdbcFieldInfoWithJdbcTypePrecisionAndScale() {
    JdbcFieldInfo fieldInfo = new JdbcFieldInfo(Types.BLOB, 1, 2);

    assertEquals(Types.BLOB, fieldInfo.getJdbcType());
    assertEquals(1, fieldInfo.getPrecision());
    assertEquals(2, fieldInfo.getScale());
  }
}

==> mingw-w64-arrow-18.1.0-3.src.tar.zst: apache-arrow-18.1.0/java/adapter/jdbc/src/test/java/org/apache/arrow/adapter/jdbc/JdbcFieldInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.arrow.adapter.jdbc;

import static org.junit.jupiter.api.Assertions.assertEquals;

import java.sql.Types;
import org.junit.jupiter.api.Test;

public class JdbcFieldInfoTest {

  @Test
  public void testCreateJdbcFieldInfoWithJdbcType() {
    JdbcFieldInfo fieldInfo = new JdbcFieldInfo(Types.BLOB);

    assertEquals(Types.BLOB, fieldInfo.getJdbcType());
    assertEquals(0, fieldInfo.getPrecision());
    assertEquals(0, fieldInfo.getScale());
  }

  @Test
  public void testCreateJdbcFieldInfoWithJdbcTypePrecisionAndScale() {
    JdbcFieldInfo fieldInfo = new JdbcFieldInfo(Types.BLOB, 1, 2);

    assertEquals(Types.BLOB, fieldInfo.getJdbcType());
    assertEquals(1, fieldInfo.getPrecision());
    assertEquals(2, fieldInfo.getScale());
  }
}
